@@ -7,6 +7,11 @@ module Delayer
   class AlreadyCanceledError < TooLate; end
   class AlreadyRunningError < TooLate; end
   class InvalidPriorityError < Error; end
+
+  class RecursiveError < Error; end
+  class NoLowerLevelError < RecursiveError; end
+  class RemainJobsError < RecursiveError; end
+
   def self.StateError(state)
     case state
     when :run
